@@ -23,10 +23,10 @@ PHYSICS_STEPS_PER_SECOND = 100
 # List of observations exposed by the environment.
 EXPOSED_OBSERVATIONS = {
     'ball', 'ball_direction', 'ball_rotation', 'ball_owned_team',
-    'ball_owned_player', 'home_team', 'home_team_direction',
-    'home_team_tired_factor', 'home_team_yellow_card', 'home_team_active',
-    'home_team_roles', 'away_team', 'away_team_direction',
-    'away_team_tired_factor', 'away_team_yellow_card', 'away_team_active',
-    'away_team_roles', 'active', 'sticky_actions', 'score', 'steps_left',
+    'ball_owned_player', 'left_team', 'left_team_direction',
+    'left_team_tired_factor', 'left_team_yellow_card', 'left_team_active',
+    'left_team_roles', 'right_team', 'right_team_direction',
+    'right_team_tired_factor', 'right_team_yellow_card', 'right_team_active',
+    'right_team_roles', 'active', 'sticky_actions', 'score', 'steps_left',
     'game_mode'
 }
